#
# spec file for package gtk2-engine-murrine
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   murrine
Name:           gtk2-engine-murrine
Version:        0.98.2
Release:        12.3
Summary:        Murrine GTK Theme Engine
License:        LGPL-2.1-only OR LGPL-3.0-only
Group:          System/GUI/XFCE
URL:            http://ftp.gnome.org/pub/GNOME/sources/murrine/
Source:         http://download.gnome.org/sources/murrine/0.98/%{_name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM murrine-missing-prototypes.patch mgorse@suse.com -- add missing prototypes.
Patch0:         murrine-missing-prototypes.patch
BuildRequires:  gtk2-devel >= 2.12.0
BuildRequires:  intltool
BuildRequires:  pkgconfig
# Only needed because we don't (and won't) support building xz tarballs by default... See bnc#697467
BuildRequires:  xz

%description
Murrine is a GTK+ 2 theme engine, that uses the Cairo vector drawing
library to render widgets. It features a modern glassy look, is elegant
and clean on the eyes, and is extremely customizable.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%configure --enable-animation
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README TODO
%{_libdir}/gtk-2.0/*/engines/*
%dir %{_datadir}/gtk-engines
%{_datadir}/gtk-engines/murrine.xml

%changelog
* Mon Apr 22 2024 Michael Gorse <mgorse@suse.com>
- Add murrine-missing-prototypes.patch: add missing prototypes.
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Wed Jan 25 2012 zaitor@opensuse.org
- Update to version 0.98.2:
  + Changed option: reliefstyle = 5 for a more controllable inset.
  + Build fixes:
  - Glib 2.31 compatibility (bgo#665022).
  - Compiles using pixman (bgo#630869).
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Drop gtk2-engine-murrine-glib.patch: fixed upstream.
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Mon Nov 28 2011 dimstar@opensuse.org
- Add gtk2-engine-murrine-glib.patch: Fix build with glib 2.31:
  only glib.h can be included.
* Mon Oct  4 2010 vuntz@opensuse.org
- Update to version 0.98.1.1:
  + Include LGPLv2.1 in the tarball.
* Fri Oct  1 2010 vuntz@opensuse.org
- Update to version 0.98.1:
  + Murrine is now dual-licensed LGPLv2.1 and LGPLv3.
  + Build fix (bgo#630869)
- Update License tag accordingly.
* Wed Sep 22 2010 vuntz@opensuse.org
- Update to version 0.98.0:
  + Too many changes to list here, please see NEWS.
  + New supported widgets: GtkExpander, GtkIconView, GtkInfoBar.
  + Many new options.
  + Improved rendering:
  - rounded GtkScale trough
  - disabled GtkScale trough
  - contrast function in GtkButton
  - better GtkTooltip theming
  - and more.
  + Various bug fixes.
- Drop gtk2-engine-murrine-0.90.3-nonvoid.patch: not needed
  anymore.
* Sun Jan 31 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Jun 24 2009 sbrabec@suse.cz
- Re-added missing baselibs.conf (bnc#354164).
* Wed May  6 2009 prusnak@suse.cz
- themes split into separate package gtk2-theme-murrine
* Wed Apr 29 2009 prusnak@suse.cz
- updated to 0.90 series (0.90.3)
  * Too many changes to be listed, let's take a summary.
  * This new version is extremely customizable with a huge number of new.
    options. Those new options allow the user to achieve an incredible.
    variety of styles.
- added themes:
  * MurrinaChrome
  * MurrinaBlu-0.32
  * MurrinaElement
  * MurrinaCandido
  * MurrinaCream
  * Murrine-Light
  * Murrine-Sky
  * Murrine-Gray
  * Kiwi
  * Neon
  * freezy-themes_2.8.0
  * shiki-colors-murrine-3.7
* Tue Nov 25 2008 sbrabec@suse.cz
- Supplement gtk2-32bit/gtk2-64bit in baselibs.conf (bnc#354164).
* Thu Aug 14 2008 prusnak@suse.cz
- updated to 0.60 (SVN revision 94)
- added Shiki-Color themes
* Thu Jun 19 2008 prusnak@suse.cz
- added themes:
  * MurrinaCandyDuo
  * MurrinaEternal
  * MurrinaGonxical
  * MurrinaGperfection
  * MurrinaGraphiteGentle
  * Murrina-Inspirat
  * MurrinaLily
  * MurrinaX-2
* Thu Jun 19 2008 prusnak@suse.cz
- added themes:
  * Caramello
  * MurrinaAquaIsh
  * MurrinaBlue
  * MurrinaElement
  * MurrinaFancyCandy
  * MurrinaGilouche
  * MurrinaLoveGray
  * MurrinaOranche
  * MurrinaOransun
  * MurrinaTango
  * MurrinaVerdeOlivo
  * MurrineRounded
* Mon Jun 16 2008 bwalle@suse.de
- new package
